@@ -6,8 +6,8 @@ use FileHandle ();
 use File::Basename ();
 use Cwd ();
 
-#$Id: Registry.pm,v 1.42 1997/11/20 23:17:59 dougm Exp $
-$Apache::Registry::VERSION = (qw$Revision: 1.42 $)[1];
+#$Id: Registry.pm,v 1.46 1998/02/20 01:36:17 dougm Exp $
+$Apache::Registry::VERSION = (qw$Revision: 1.46 $)[1];
 
 $Apache::Registry::Debug ||= 0;
 # 1 => log recompile in errorlog
@@ -69,7 +69,7 @@ sub handler {
 
 	# second pass cares for slashes and words starting with a digit
 	$script_name =~ s{
-			  (/)        # directory
+			  (/+)       # directory
 			  (\d?)      # package's first character
 			 }[
 			   "::" . ($2 ? sprintf("_%2x",unpack("C",$2)) : "")
@@ -85,9 +85,9 @@ sub handler {
 	chdir File::Basename::dirname($r->filename);
 
 	if (
-	    exists $Apache::Registry->{$package}{mtime}
+	    exists $Apache::Registry->{$package}{'mtime'}
 	    &&
-	    $Apache::Registry->{$package}{mtime} <= $mtime
+	    $Apache::Registry->{$package}{'mtime'} <= $mtime
 	   ){
 	    # we have compiled this subroutine already, nothing left to do
  	} else {
@@ -104,6 +104,9 @@ sub handler {
 	    # compile this subroutine into the uniq package name
             $r->log_error("Apache::Registry::handler eval-ing") if $Debug && $Debug & 4;
  	    undef &{"$package\::handler"} unless $Debug && $Debug & 4; #avoid warnings
+	    if($package->can('undef_functions')) {
+		$package->undef_functions;
+	    }
 	    $r->clear_rgy_endav($script_name);
 
 	    my $eval = join(
@@ -124,7 +127,7 @@ sub handler {
 	    }
             $r->log_error(qq{Compiled package \"$package\" for process $$})
 	       if $Debug && $Debug & 1;
-	    $Apache::Registry->{$package}{mtime} = $mtime;
+	    $Apache::Registry->{$package}{'mtime'} = $mtime;
 	}
 
 	my $cv = \&{"$package\::handler"};
@@ -135,25 +138,27 @@ sub handler {
 	}
 	$^W = $oldwarn;
 
-	my $err = $@;
-	if(exists $INC{'CGI.pm'}
-	   && ! $Apache::Registry::CGI_versioncheck_done ) {
-	    $Apache::Registry::CGI_versioncheck_done++;
-	    require Exporter;
-	    eval { Exporter::require_version('CGI', 2.36); }; 
-	    $err .= $@ if $@;
+	my $errsv = "";
+	if($@) {
+	    $errsv = $@;
+	    $@ = ''; #XXX fix me, if we don't do this Apache::exit() breaks
+	    $@{"Apache::Registry"} = $errsv if $Apache::ERRSV_CAN_BE_HTTP;
 	}
-	if ($err) {
-	    $r->log_error($err);
+
+	if($errsv) {
+	    $r->log_error($errsv);
 	    return SERVER_ERROR unless $Debug && $Debug & 2;
 	    return Apache::Debug::dump($r, SERVER_ERROR);
 	}
 
+=pod
+	#XXX
 	if(my $loc = $r->header_out("Location")) {
 	    if($r->status == 200 and substr($loc, 0, 1) ne "/") {
 		return REDIRECT;
 	    }
 	}
+=cut
 	return $r->status;
     } else {
 	return NOT_FOUND unless $Debug && $Debug & 2;
@@ -170,7 +175,7 @@ sub compile {
 #XXX not good enough yet
 my(%switches) = (
    'T' => sub {
-       Apache::warn("Apache::Registry: -T switch ignored, ".
+       Apache::warn("Apache::Registry: T switch ignored, ".
 		    "enable with 'PerlTaintCheck On'\n")
 	   unless $Apache::__T; "";
    },
@@ -201,6 +206,8 @@ sub parse_cmdline {
 #trick so we show up under CPAN/modules/by-module/CGI/
 package CGI::mod_perl;
 
+sub DESTROY {}
+
 1;
 
 __END__
@@ -279,15 +286,15 @@ The environment variable B<GATEWAY_INTERFACE> is set to C<CGI-Perl/1.1>.
 Normally when a Perl script is run from the command line or under CGI,
 arguments on the `#!' line are passed to the perl interpreter for processing.
 
-Apache::Registry currently only honors the C<-w> switch and will turn
+Apache::Registry currently only honors the B<-w> switch and will turn
 on warnings using the C<$^W> global variable.  Another common switch
-used with CGI scripts is C<-T> to turn on taint checking.  This can
+used with CGI scripts is B<-T> to turn on taint checking.  This can
 only be enabled when the server starts with the configuration
 directive:
 
  PerlTaintCheck On
 
-However, if taint checking is not enabled, but the C<-T> switch is seen,
+However, if taint checking is not enabled, but the B<-T> switch is seen,
 Apache::Registry will write a warning to the error_log.
 
 =head1 DEBUGGING
@@ -316,6 +323,5 @@ perl(1), mod_perl(3), Apache(3), Apache::Debug(3)
 
 =head1 AUTHORS
 
-Andreas Koenig <andreas.koenig@franz.ww.tu-berlin.de> and
-Doug MacEachern <dougm@osf.org>
+Andreas J. Koenig and Doug MacEachern
 
